DEFAULT_SETTINGS = {
    'AUTOCONFIG_URL_PREFIXES': {
        'shorty': '',
    },
}

SETTINGS = {
    'INSTALLED_APPS': [
        'django.contrib.admin',
        'nuit',
    ],
    'NUIT_GLOBAL_TITLE': 'Shorty',
}
